@@ -33,8 +33,8 @@ class VncPreferences : public KCModule
     Q_OBJECT
 
 public:
-    explicit VncPreferences(QWidget *parent = 0, const QVariantList &args = QVariantList());
-    ~VncPreferences();
+    explicit VncPreferences(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+    ~VncPreferences() override;
 
     void save() override;
     void load() override;
